{% extends "base.html" %}
{% block head %}
{{ super() }}
<link href="{{ url_for('static', filename='css/cover.css', version=version) }}" rel="stylesheet">
{% endblock %}
{% block content_class %}{{ super() }} d-flex flex-column h-100 p-3 mx-auto{% endblock %}
{% block content %}
<main role="main" class="text-center mt-auto">
    <div style="font-size: 100px;">✝</div>
    <h1 class="cover-heading pb-4">Ezra 聖經語意搜尋</h1>
    <form id="search-form" class="form mb-4" action="/search" novalidate>
        <div class="form-row">
            <div class="col">
                <input id="search-box" class="form-control form-control-lg shadow-sm" name="q" ref="keyword"
                    type="search" inputmode="search" aria-label="搜尋" required autofocus>
            </div>
            <div class="col-auto">
                <button class="btn btn-lg btn-outline-success shadow-sm" type="submit">
                    <i class="fas fa-search"></i>
                </button>
            </div>
        </div>
    </form>
    <p class="lead d-none d-sm-block">
        語意搜尋・查找關聯經文・<a href="#" data-toggle="modal" data-target="#aboutModal">關於 Ezra</a>
    </p>
</main>
{% endblock %}