all = [
    "gen",
    "ex",
    "lev",
    "num",
    "deut",
    "josh",
    "judg",
    "ruth",
    "1sam",
    "2sam",
    "1kin",
    "2kin",
    "1chr",
    "2chr",
    "ezra",
    "neh",
    "esth",
    "job",
    "ps",
    "prov",
    "eccl",
    "song",
    "is",
    "jer",
    "lam",
    "ezek",
    "dan",
    "hos",
    "joel",
    "amos",
    "obad",
    "jon",
    "mic",
    "nah",
    "hab",
    "zeph",
    "hag",
    "zech",
    "mal",
    "matt",
    "mark",
    "luke",
    "john",
    "acts",
    "rom",
    "1cor",
    "2cor",
    "gal",
    "eph",
    "phil",
    "col",
    "1thess",
    "2thess",
    "1tim",
    "2tim",
    "titus",
    "philem",
    "heb",
    "james",
    "1pet",
    "2pet",
    "1john",
    "2john",
    "3john",
    "jude",
    "rev",
]


def get_books(start: str, end: str):
    return all[all.index(start) : all.index(end) + 1]


ranges = {
    "nt": get_books("matt", "rev"),
    "ot": get_books("gen", "mal"),
    "gospels": get_books("matt", "john"),
    "letters": get_books("rom", "jude"),
    "torah": get_books("gen", "deut"),
    "history": get_books("josh", "esth"),
    "poetry": get_books("job", "song"),
    "prophecy": get_books("is", "mal"),
}
